summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/timeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/timeedit.h')
-rw-r--r--kalarm/lib/timeedit.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kalarm/lib/timeedit.h b/kalarm/lib/timeedit.h
index 45c0abd8..7be73c1f 100644
--- a/kalarm/lib/timeedit.h
+++ b/kalarm/lib/timeedit.h
@@ -47,15 +47,16 @@ class TimeSpinBox;
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class TimeEdit : public QHBox
+class TimeEdit : public TQHBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit TimeEdit(TQWidget* parent = 0, const char* name = 0);
+ explicit TimeEdit(TQWidget* tqparent = 0, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the widget is read-only for the user. If read-only,
@@ -64,7 +65,7 @@ class TimeEdit : public QHBox
* @param readOnly True to set the widget read-only, false to set it read-write.
*/
virtual void setReadOnly(bool readOnly);
- /** Returns true if the widget tqcontains a valid value. */
+ /** Returns true if the widget contains a valid value. */
bool isValid() const;
/** Sets whether the edit value is valid.
* If newly invalid, the value is displayed as asterisks.
@@ -47,15 +47,16 @@ class TimeSpinBox;
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/